<?php

use Symfony\Component\Console\Output\ConsoleOutput;

/**
 * Implements hook_drush_command().
 */
function feedbackjs_drush_command() {
  $commands = [];

  $commands['send-responses-to-bigquery'] = [
    'description' => 'Send survey tool responses to Big Query',
    'drupal dependencies' => ['feedbackjs'],
    'aliases' => ['bqUpdate']
  ];

  return $commands;
}

/**
 * Call back function drush_custom_drush_command_send_responses_to_bigquery()
 * The call back function name in the  following format
 *   drush_{module_name}_{item_id_for_command}()
 */
function drush_feedbackjs_send_responses_to_bigquery() {
  $responseExport = \Drupal::service('simple_survey.response_export');
  $bigQuery = \Drupal::service('simple_survey.big_query');

  $output = new ConsoleOutput();

  if (!$bigQuery->checkConfigured()) {
    $output->writeln('<error>Big Query is not configured.</error>');
  }
  else {
    $output->writeln('<info>Converting Data</info>');

    $csv = $responseExport->convertDataToCsv();

    $output->writeln('<info>Submitting to BigQuery</info>');

    if ($bigQuery->updateTable($csv)) {
      $output->writeln('<info>Submission Complete.</info>');
    }
    else {
      $output->writeln('<error>Submission Failed. Check the error log for more details.</error>');
    }

  }
}
