<?php

namespace Drupal\simple_survey\Controller;

use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\Query\QueryException;

/**
 * Provides a listing of Surveys.
 */
class SimpleSurveyListBuilder extends ConfigEntityListBuilder {

  /**
   * {@inheritdoc}
   */
  public function buildHeader() {
    $header['label'] = $this->t('Survey');
    $header['id'] = $this->t('Machine name');
    $header['sqcount'] = $this->t('Number of Questions');
    $header['srcount'] = $this->t('Number of Responses');
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity) {

    $surveyQuestionCount = \Drupal::service('entity_type.manager')->getStorage('survey_question')->getQuery()
      ->condition('survey', $entity->id())
      ->count()
      ->execute();

    try {
      $surveyResponseCount = \Drupal::service('entity_type.manager')->getStorage('survey_response')->getQuery()
        ->condition('survey', $entity->id())
        ->count()
        ->execute();
    }
    catch (QueryException $error) {
      $surveyResponseCount = 0;
    }

    $row['label'] = $entity->label();
    $row['id'] = $entity->id();
    $row['sqcount'] = $surveyQuestionCount;
    $row['srcount'] = $surveyResponseCount;

    return $row + parent::buildRow($entity);
  }
}
